@@ -13,7 +13,7 @@ use lib '../..';
 
 use base qw(App::Followme::ConfiguredObject);
 
-our $VERSION = "1.04";
+our $VERSION = "1.05";
 
 use constant COMMAND_START => '<!-- ';
 use constant COMMAND_END => '-->';
@@ -352,7 +352,7 @@ sub parse_sections {
     # Extract sections from page
     
     my $sections = {};
-    my @lines = split(/\n/, $page);
+    my @lines = map {"$_\n"} split(/\n/, $page);
     $self->parse_block($sections, \@lines, '');
 
     # Combine lines in each section into a single string
